pub struct Snapshot { /* private fields */ }Expand description
Point-in-time source-data view used before promotion into core domain records.
Implementations
Sourceimpl Snapshot
impl Snapshot
Sourcepub const fn builder() -> SnapshotBuilder
pub const fn builder() -> SnapshotBuilder
Returns the builder evidence carried by this source-lineage value.
Sourcepub const fn provenance(&self) -> &Provenance
pub const fn provenance(&self) -> &Provenance
Returns the provenance evidence carried by this source-lineage value.
Sourcepub const fn owner_provider_id(&self) -> Option<&ProviderRecordId>
pub const fn owner_provider_id(&self) -> Option<&ProviderRecordId>
Returns the owner provider id evidence carried by this source-lineage value.
Sourcepub const fn animal_provider_id(&self) -> Option<&ProviderRecordId>
pub const fn animal_provider_id(&self) -> Option<&ProviderRecordId>
Returns the animal provider id evidence carried by this source-lineage value.
Sourcepub const fn location_provider_id(&self) -> Option<&ProviderRecordId>
pub const fn location_provider_id(&self) -> Option<&ProviderRecordId>
Returns the location provider id evidence carried by this source-lineage value.
Sourcepub const fn service_type_provider_id(&self) -> Option<&ProviderRecordId>
pub const fn service_type_provider_id(&self) -> Option<&ProviderRecordId>
Returns the service type provider id evidence carried by this source-lineage value.
Sourcepub const fn provider_status(&self) -> Option<&ProviderStatus>
pub const fn provider_status(&self) -> Option<&ProviderStatus>
Returns the provider status evidence carried by this source-lineage value.
Sourcepub const fn relationship(&self) -> &OwnerPetRelationship
pub const fn relationship(&self) -> &OwnerPetRelationship
Returns the relationship evidence carried by this source-lineage value.