pub struct SnapshotBuilder { /* private fields */ }Expand description
Builder for assembling a source snapshot with validated provider identifiers.
Implementations
Sourceimpl SnapshotBuilder
impl SnapshotBuilder
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Assembles source-lineage data from already validated domain parts without reinterpreting authority.
Sourcepub fn provenance(self, provenance: Provenance) -> Self
pub fn provenance(self, provenance: Provenance) -> Self
Returns the provenance evidence carried by this source snapshot.
Sourcepub fn owner_provider_id(self, id: impl Into<Option<ProviderRecordId>>) -> Self
pub fn owner_provider_id(self, id: impl Into<Option<ProviderRecordId>>) -> Self
Returns the owner provider id evidence carried by this source snapshot.
Sourcepub fn animal_provider_id(self, id: impl Into<Option<ProviderRecordId>>) -> Self
pub fn animal_provider_id(self, id: impl Into<Option<ProviderRecordId>>) -> Self
Returns the animal provider id evidence carried by this source snapshot.
Sourcepub fn location_provider_id(
self,
id: impl Into<Option<ProviderRecordId>>,
) -> Self
pub fn location_provider_id( self, id: impl Into<Option<ProviderRecordId>>, ) -> Self
Returns the location provider id evidence carried by this source snapshot.
Sourcepub fn service_type_provider_id(
self,
id: impl Into<Option<ProviderRecordId>>,
) -> Self
pub fn service_type_provider_id( self, id: impl Into<Option<ProviderRecordId>>, ) -> Self
Returns the service type provider id evidence carried by this source snapshot.
Sourcepub fn provider_status(self, status: impl Into<Option<ProviderStatus>>) -> Self
pub fn provider_status(self, status: impl Into<Option<ProviderStatus>>) -> Self
Returns the provider status evidence carried by this source snapshot.
Sourcepub fn relationship(self, relationship: OwnerPetRelationship) -> Self
pub fn relationship(self, relationship: OwnerPetRelationship) -> Self
Returns the relationship evidence carried by this source snapshot.